﻿using C1.CollectionView;
using C1.Xamarin.Forms.Grid;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.Linq;
using System.Threading.Tasks;
using Xamarin.Forms;
using Xamarin.Forms.Xaml;

namespace C1GridSample
{
    [XamlCompilation(XamlCompilationOptions.Compile)]
    public partial class SampleGridView : ContentView
    {
        private readonly FlexGrid grid;
        private readonly ObservableCollection<Person> peopleCollection;
        private C1CollectionView<Person> peopleCollectionView;

        public SampleGridView()
        {
            InitializeComponent();

            peopleCollection = new ObservableCollection<Person>();

            grid = new FlexGrid();
            gridContainer.Content = grid;
            grid.Rows.CollectionChanged += Rows_CollectionChanged;

            var samplePeople = SampleData.GetSamplePeople(100).ToList();
            foreach (var person in samplePeople)
            {
                peopleCollection.Add(person);
            }

            peopleCollectionView = new C1CollectionView<Person>(peopleCollection);
            peopleCollectionView.GroupAsync(p => p.Country);
            peopleCollectionView.SortAsync(p => p.Country);
            grid.IsAnimated = false;
            grid.ItemsSource = peopleCollectionView;

        }
        private void Rows_CollectionChanged(object sender, NotifyCollectionChangedEventArgs e)
        {
            if (e.Action == NotifyCollectionChangedAction.Add)
            {
                for (int i = 0; i < e.NewItems.Count; i++)
                {
                    var groupRow = (sender as GridRowCollection)[e.NewStartingIndex + i] as GridGroupRow;
                    if (groupRow != null)
                        groupRow.IsCollapsed = true;
                }
            }
        }

        public async Task PopulateGrid()
        {
            var samplePeople = SampleData.GetSamplePeople(100).ToList();
            int count = 0;
            List<Person> collection = peopleCollection.ToList();
            List<Person> duplicateCollection = new List<Person>();
            foreach (var person in samplePeople)
            {
                List<Person> tempCollection = peopleCollection.Where(x => x.Id == person.Id && x.Name == person.Name && x.Country == person.Country).ToList();

                if (tempCollection.Count == 0)
                {
                    peopleCollection.Add(person);
                }
                else
                {
                    duplicateCollection.AddRange(tempCollection);
                    count++;
                }
            }
            foreach (Person person in duplicateCollection)
            {
                collection.Remove(person);
            }
            foreach(Person person in collection)
            {
                peopleCollection.Remove(person);
            }
            peopleCollectionView = new C1CollectionView<Person>(peopleCollection);
        }

        private async void RefreshButton_Clicked(object sender, System.EventArgs e)
        {
            await PopulateGrid();
        }
    }
}